@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-08-18'; # DATE
-our $VERSION = '1.58'; # VERSION
+our $DATE = '2016-08-30'; # DATE
+our $VERSION = '1.59'; # VERSION
 
 use 5.010001;
 use strict;
@@ -737,7 +737,8 @@ sub _parse_argv1 {
 
         require Getopt::Long;
         my $old_go_conf = Getopt::Long::Configure(
-            'pass_through', 'no_ignore_case', 'bundling', 'no_auto_abbrev');
+            'pass_through', 'no_ignore_case', 'bundling', 'no_auto_abbrev',
+            'no_getopt_compat');
         my $co = $self->common_opts // {};
         for my $k (keys %$co) {
             push @go_spec, $co->{$k}{getopt} => sub {
@@ -1442,7 +1443,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.58 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-08-18.
+This document describes version 1.59 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-08-30.
 
 =head1 DESCRIPTION
 
